# cellranger_atac

**DOI:** [10.5281/zenodo.8423331](https://doi.org/10.5281/zenodo.8423331)

## Available Versions
- **Version 2.1.0**
  - [Download](https://zenodo.org/record/8423332/files/cellranger_atac_2.1.0.img)
  - **MD5:** `bcfbe398257814f4cf349ca8e3de2705`
  - **DOI:** [10.5281/zenodo.8423332](https://doi.org/10.5281/zenodo.8423332)
  - **Size:** 728.86 MB
  - **Binaries:** 0 available

## Binaries (1 total)

```cellranger-atac```
